@@ -9,7 +9,7 @@ from selenium.common.exceptions import WebDriverException
 from html_processing.parser import get_html_parser
 
 
-def lxml_connect(url):
+def lxml_connect(url, custom_element=None):
     """
     Connects to URL and returns the HTML Tree
     :param url: The URL to the target data source
@@ -18,7 +18,7 @@ def lxml_connect(url):
     :rtype: HtmlElement
     """
 
-    parser = get_html_parser()
+    parser = get_html_parser() if custom_element is None else get_html_parser(custom_element)
     driver = dpp_common_utils.selenium.get_driver(True)
     __check_url(url)
     try:
@@ -28,6 +28,7 @@ def lxml_connect(url):
 
     sleep(3)  # sleep - the script has to be loaded and this needs time
     res = driver.page_source
+    driver.quit()
 
     html_tree: HtmlElement = etree.fromstring(res, parser=parser)
     return html_tree
